from setuptools import setup, find_packages

setup(
    name='capslovess',
    version='0.1.0',
    description='Client library for Captchasolver API',
    author='zalos',
    author_email='bza55losxsgytt@gmail.com',
    packages=find_packages(),
    install_requires=['requests'],
    python_requires='>=3.7',
)
